<?php

namespace Litecms\Affiliate\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Affiliate\Models\Affiliate;

class AffiliatePolicy
{

    /**
     * Determine if the given user can view the affiliate.
     *
     * @param UserPolicy $user
     * @param Affiliate $affiliate
     *
     * @return bool
     */
    public function view(UserPolicy $user, Affiliate $affiliate)
    {
        if ($user->canDo('affiliate.affiliate.view') && $user->isAdmin()) {
            return true;
        }

        return $affiliate->user_id == user_id() && $affiliate->user_type == user_type();
    }

    /**
     * Determine if the given user can create a affiliate.
     *
     * @param UserPolicy $user
     * @param Affiliate $affiliate
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('affiliate.affiliate.create');
    }

    /**
     * Determine if the given user can update the given affiliate.
     *
     * @param UserPolicy $user
     * @param Affiliate $affiliate
     *
     * @return bool
     */
    public function update(UserPolicy $user, Affiliate $affiliate)
    {
        if ($user->canDo('affiliate.affiliate.edit') && $user->isAdmin()) {
            return true;
        }

        return $affiliate->user_id == user_id() && $affiliate->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given affiliate.
     *
     * @param UserPolicy $user
     * @param Affiliate $affiliate
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Affiliate $affiliate)
    {
        return $affiliate->user_id == user_id() && $affiliate->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given affiliate.
     *
     * @param UserPolicy $user
     * @param Affiliate $affiliate
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Affiliate $affiliate)
    {
        if ($user->canDo('affiliate.affiliate.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given affiliate.
     *
     * @param UserPolicy $user
     * @param Affiliate $affiliate
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Affiliate $affiliate)
    {
        if ($user->canDo('affiliate.affiliate.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
