<?php

namespace Litecms\Affiliate\Providers;

use Illuminate\Support\ServiceProvider;

class AffiliateServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'affiliate');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'affiliate');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.affiliate', function ($app) {
            return $this->app->make('Litecms\Affiliate\Affiliate');
        });

                // Bind Affiliate to repository
        $this->app->bind(
            'Litecms\Affiliate\Interfaces\AffiliateRepositoryInterface',
            \Litecms\Affiliate\Repositories\Eloquent\AffiliateRepository::class
        );

        $this->app->register(\Litecms\Affiliate\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\Affiliate\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.affiliate'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/affiliate.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/affiliate')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/affiliate')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
